@@ -8,7 +8,6 @@
     :copyright: Copyright 2014 Mark Mikofski
     :license: BSD, see LICENSE for details.
 """
-from __future__ import unicode_literals
 from io import open  # for opening files with encoding in Python 2
 import os
 import re
@@ -477,7 +476,8 @@ class MatMixin(object):
         :type idx: int
         """
         idx0 = idx  # original index
-        while (self.tokens[idx][0] is Token.Text and
+        while ((self.tokens[idx][0] is Token.Text or
+                self.tokens[idx][0] is Token.Text.Whitespace) and
                self.tokens[idx][1] in [' ', '\n', '\t']):
             idx += 1
         return idx - idx0  # whitespace
@@ -495,6 +495,10 @@ class MatMixin(object):
             idx += 1
         return idx - idx0  # indentation
 
+    def _is_newline(self, idx):
+        """ Returns true if the token at index is a newline """
+        return self.tokens[idx][0] in (Token.Text, Token.Text.Whitespace) and self.tokens[idx][1]=='\n'
+
 
 def skip_whitespace(tks):
     """ Eats whitespace from list of tokens """
@@ -624,7 +628,7 @@ class MatFunction(MatObject):
                     wht = tks.pop()  # We expect a newline
                 except IndexError:
                     break
-                if wht[0] == Token.Text and wht[1] == '\n':
+                if wht[0] in (Token.Text, Token.Text.Whitespace) and wht[1] == '\n':
                     self.docstring += '\n'
                 # Skip whitespace
                 try:
@@ -767,15 +771,15 @@ class MatClass(MatMixin, MatObject):
             if self._tk_eq(idx, (Token.Operator, '<')):
                 idx += 1
                 # newline terminates superclasses
-                while self._tk_ne(idx, (Token.Text, '\n')):
+                while not self._is_newline(idx):
                     idx += self._blanks(idx)  # skip blanks
                     # concatenate base name
                     base_name = ''
                     while not self._whitespace(idx):
                         base_name += self.tokens[idx][1]
                         idx += 1
-                    # if newline, don't increment index
-                    if self._tk_ne(idx, (Token.Text, '\n')):
+                    # If it's a newline, we are done parsing.
+                    if not self._is_newline(idx):
                         idx += 1
                     if base_name:
                         self.bases.append(base_name)
@@ -785,7 +789,7 @@ class MatClass(MatMixin, MatObject):
                         idx += 1
                 idx += 1  # end of super classes
             # newline terminates classdef signature
-            elif self._tk_eq(idx, (Token.Text, '\n')):
+            elif self._is_newline(idx):
                 idx += 1  # end of classdef signature
             # =====================================================================
             # docstring
@@ -795,7 +799,7 @@ class MatClass(MatMixin, MatObject):
                 self.docstring += self.tokens[idx][1].lstrip('%')
                 idx += 1
                 # append newline to docstring
-                if self._tk_eq(idx, (Token.Text, '\n')):
+                if self._is_newline(idx):
                     self.docstring += self.tokens[idx][1]
                     idx += 1
                 # skip tab
@@ -829,44 +833,44 @@ class MatClass(MatMixin, MatObject):
                                 idx += whitespace
                             else:
                                 idx += 1
-                                
+
                         # =========================================================
                         # long docstring before property
                         if self.tokens[idx][0] is Token.Comment:
                             # docstring
                             docstring = ''
-                            
+
                             # Collect comment lines
                             while self.tokens[idx][0] is Token.Comment:
                                 docstring += self.tokens[idx][1].lstrip('%')
-                                idx += 1 
+                                idx += 1
                                 idx += self._blanks(idx)
-                                
+
                                 try:
                                     # Check if end of line was reached
-                                    if self.tokens[idx][0] == Token.Text and self.tokens[idx][1] == '\n':
+                                    if self._is_newline(idx):
                                         docstring += '\n'
                                         idx += 1
                                         idx += self._blanks(idx)
-                                        
-                                    # Check if variable name is next                                        
+
+                                    # Check if variable name is next
                                     if self.tokens[idx][0] is Token.Name:
                                         prop_name = self.tokens[idx][1]
                                         self.properties[prop_name] = {'attrs': attr_dict}
                                         self.properties[prop_name]['docstring'] = docstring
                                         break
-                                    
-                                    # If there is an empty line at the end of 
+
+                                    # If there is an empty line at the end of
                                     # the comment: discard it
-                                    elif self.tokens[idx][0] == Token.Text and self.tokens[idx][1] == '\n':
+                                    elif self._is_newline(idx):
                                         docstring = ''
                                         idx += self._whitespace(idx)
                                         break
-                                    
+
                                 except IndexError:
                                     # EOF reached, quit gracefully
-                                    break    
-                            
+                                    break
+
                         # with "%:" directive trumps docstring after property
                         if self.tokens[idx][0] is Token.Name:
                             prop_name = self.tokens[idx][1]
@@ -890,20 +894,20 @@ class MatClass(MatMixin, MatObject):
                                   self.tokens[idx][0] == Token.Name or \
                                   self.tokens[idx][0] == Token.Text:
                                 idx += 1
-                                
+
                             if self._tk_eq(idx, (Token.Punctuation, ';')):
                                 continue
-                            
+
                         # subtype of Name EG Name.Builtin used as Name
                         elif self.tokens[idx][0] in Token.Name.subtypes:  # @UndefinedVariable
-                        
+
                             prop_name = self.tokens[idx][1]
                             warn_msg = ' '.join(['[%s] WARNING %s.%s.%s is',
                                                  'a Builtin Name'])
                             logger.debug(warn_msg, MAT_DOM, self.module, self.name, prop_name)
                             self.properties[prop_name] = {'attrs': attr_dict}
                             idx += 1
-                            
+
                             # skip size, class and functions specifiers
                             # TODO: Parse old and new style property extras
                             while self._tk_eq(idx, (Token.Punctuation, '@')) or \
@@ -919,10 +923,10 @@ class MatClass(MatMixin, MatObject):
                                   self.tokens[idx][0] == Token.Name or \
                                   self.tokens[idx][0] == Token.Text:
                                 idx += 1
-                                
+
                             if self._tk_eq(idx, (Token.Punctuation, ';')):
                                 continue
-                            
+
                         elif self._tk_eq(idx, (Token.Keyword, 'end')):
                             idx += 1
                             break
@@ -931,14 +935,14 @@ class MatClass(MatMixin, MatObject):
                             idx += 1
                             # A comment might come after semi-colon
                             idx += self._blanks(idx)
-                            if self._tk_eq(idx, (Token.Text, '\n')):
+                            if self._is_newline(idx):
                                 idx += 1
                                 # Property definition is finished; add missing values
                                 if 'default' not in self.properties[prop_name].keys():
                                     self.properties[prop_name]['default'] = None
                                 if 'docstring' not in self.properties[prop_name].keys():
                                     self.properties[prop_name]['docstring'] = None
-                                                                         
+
                                 continue
                             elif self.tokens[idx][0] is Token.Comment:
                                 docstring = self.tokens[idx][1].lstrip('%')
@@ -962,7 +966,7 @@ class MatClass(MatMixin, MatObject):
                             # keep reading until newline or comment
                             # only if all punctuation pairs are closed
                             # and comment is **not** continuation ellipsis
-                            while ((self._tk_ne(idx, (Token.Text, '\n')) and
+                            while ((not self._is_newline(idx) and
                                     self.tokens[idx][0] is not Token.Comment) or
                                    punc_ctr > 0 or
                                    (self.tokens[idx][0] is Token.Comment and
@@ -982,11 +986,11 @@ class MatClass(MatMixin, MatObject):
                                       token[1].startswith('...')):
                                     idx += 1  # skip ellipsis comments
                                     # include newline which should follow comment
-                                    if self._tk_eq(idx, (Token.Text, '\n')):
+                                    if self._is_newline(idx):
                                         default += '\n'
                                         idx += 1
                                     continue
-                                elif self._tk_eq(idx - 1, (Token.Text, '\n')):
+                                elif self._is_newline(idx - 1):
                                     idx += self._blanks(idx)
                                     continue
                                 default += token[1]
@@ -1008,7 +1012,7 @@ class MatClass(MatMixin, MatObject):
                         elif self.tokens[idx][0] is Token.Comment:
                             # skip this comment
                             idx += 1
-                                
+
                         idx += self._whitespace(idx)
                     idx += 1
                 # =================================================================
@@ -1051,8 +1055,8 @@ class MatClass(MatMixin, MatObject):
                             # find methods
                             meth = MatMethod(self.module, self.tokens[idx:],
                                              self, attr_dict)
-                            # Detect getter/setter methods - these are not documented
-                            if not meth.name.split('.')[0] in ['get', 'set']:
+                            # Detect getter/setter methods - these are not documented                            
+                            if not (meth.name.startswith('get.') or meth.name.startswith('set.')):
                                 self.methods[meth.name] = meth  # update methods
                             idx += meth.reset_tokens()  # reset method tokens and index
 
@@ -1315,7 +1319,7 @@ class MatScript(MatObject):
                 wht = tks.pop()  # We expect a newline
             except IndexError:
                 break
-            if wht[0] == Token.Text and wht[1] == '\n':
+            if wht[0] in (Token.Text, Token.Text.Whitespace) and wht[1] == '\n':
                 self.docstring += '\n'
             # Skip whitespace
             try:
